@@ -1,4 +1,4 @@
-/* 
+/*
 **
 **  CursesBoot.c -- the bootstrap function
 **
@@ -476,6 +476,9 @@ XS(boot_Curses)
 #ifdef A_BOLD
     C_NEWCS("A_BOLD",                         A_BOLD);
 #endif
+#ifdef A_ITALIC
+    C_NEWCS("A_ITALIC",                         A_ITALIC);
+#endif
 #ifdef A_CHARTEXT
     C_NEWCS("A_CHARTEXT",                     A_CHARTEXT);
 #endif
@@ -881,6 +884,24 @@ XS(boot_Curses)
 #ifdef BUTTON4_RESERVED_EVENT
     C_NEWCS("BUTTON4_RESERVED_EVENT",         BUTTON4_RESERVED_EVENT);
 #endif
+#ifdef BUTTON5_RELEASED
+    C_NEWCS("BUTTON5_RELEASED",               BUTTON5_RELEASED);
+#endif
+#ifdef BUTTON5_PRESSED
+    C_NEWCS("BUTTON5_PRESSED",                BUTTON5_PRESSED);
+#endif
+#ifdef BUTTON5_CLICKED
+    C_NEWCS("BUTTON5_CLICKED",                BUTTON5_CLICKED);
+#endif
+#ifdef BUTTON5_DOUBLE_CLICKED
+    C_NEWCS("BUTTON5_DOUBLE_CLICKED",         BUTTON5_DOUBLE_CLICKED);
+#endif
+#ifdef BUTTON5_TRIPLE_CLICKED
+    C_NEWCS("BUTTON5_TRIPLE_CLICKED",         BUTTON5_TRIPLE_CLICKED);
+#endif
+#ifdef BUTTON5_RESERVED_EVENT
+    C_NEWCS("BUTTON5_RESERVED_EVENT",         BUTTON5_RESERVED_EVENT);
+#endif
 #ifdef BUTTON_CTRL
     C_NEWCS("BUTTON_CTRL",                    BUTTON_CTRL);
 #endif
